@@ -5,31 +5,10 @@ import pomace
 from . import Script
 
 
-class Salesflare(Script):
-
-    URL = "https://integrations.salesflare.com/s/tortii"
-    SKIP = True
-
-    def run(self, page) -> pomace.Page:
-        pomace.log.info("Launching form")
-        page = page.click_request_this_listing(wait=0)
-        page.fill_email(pomace.fake.email)
-        page.fill_company(pomace.fake.company)
-
-        pomace.log.info("Submitting form")
-        return page.click_submit(wait=1)
-
-    def check(self, page) -> bool:
-        success = "Thank you for your request" in page
-        page.click_close(wait=0.1)
-        return success
-
-
 class TommyBryant(Script):
-
     URL = "https://www.cityoftarrant.com/contact"
 
-    def run(self, page) -> pomace.Page:
+    def run(self, page: pomace.Page) -> pomace.Page:
         person = pomace.fake.person
 
         pomace.log.info(f"Beginning iteration as {person}")
@@ -50,46 +29,25 @@ class TommyBryant(Script):
         page.fill_captcha("Blue")
         return page.click_submit()
 
-    def check(self, page) -> bool:
+    def check(self, page: pomace.Page) -> bool:
         return "submission has been received" in page
 
 
-class JamesCraig(Script):
-
-    URL = "https://chiefjamescraig.com"
-
-    def run(self, page) -> pomace.Page:
-        person = pomace.fake.person
-
-        pomace.log.info(f"Beginning iteration as {person}")
-        page.fill_first_name(person.first_name)
-        page.fill_email(person.email)
-        page.fill_phone(person.phone)
-        page.click_optional(wait=0)
-        return page.click_submit()
-
-    def check(self, page) -> bool:
-        return "winred" in page.url
-
-
 class PatriotPage(Script):
-
     URL = "https://patriotpage.org"
 
-    def run(self, page) -> pomace.Page:
-        page.browser.reload()
+    def run(self, page: pomace.Page) -> pomace.Page:
         person = pomace.fake.person
 
         pomace.log.info(f"Beginning iteration as {person}")
         page = page.click_create_an_account()
         page.fill_email(person.email)
         page.fill_confirm_email(person.email)
-        password = pomace.fake.password
-        page.fill_password(password)
-        page.fill_confirm_password(password)
+        page.fill_password(person.password)
+        page.fill_confirm_password(person.password)
         page.fill_first_name(person.first_name)
         page.fill_last_name(person.last_name)
-        page.fill_nickname((person.first_name + person.last_name).lower())
+        page.fill_nickname(person.nickname)
         page.fill_country("United States")
         page.fill_selection(
             random.choice(
@@ -111,5 +69,5 @@ class PatriotPage(Script):
         pomace.log.info("Creating account")
         return page.click_create_account(wait=1)
 
-    def check(self, page) -> bool:
+    def check(self, page: pomace.Page) -> bool:
         return "We’re almost there!" in page
